@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: downloader-view.c,v 1.13 2003/05/25 18:59:59 xan Exp $
+ *  $Id: downloader-view.c,v 1.17 2003/06/22 00:37:32 mpeseng Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -40,6 +40,8 @@
 #include <gtk/gtkprogressbar.h>
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
 
+#define CONF_DOWNLOADING_SHOW_DETAILS "/apps/epiphany/dialogs/downloader_show_details"
+
 enum
 {
 	DOWNLOAD_REMOVE,
@@ -403,12 +405,12 @@ downloader_view_update_details (DownloaderViewPrivate *priv,
 
 	if (details->speed > 0)
 	{
-		sprintf (buffer, "%s at %.1f KB/s", buffer, details->speed);
+		sprintf (buffer, _("%s at %.1f KB/s"), buffer, details->speed);
 	}
 	gtk_label_set_text (GTK_LABEL (priv->details_status),
 			    buffer);
 
-	format_time (buffer, details->elapsed/1000000);
+	format_time (buffer, details->elapsed);
 	gtk_label_set_text (GTK_LABEL (priv->details_elapsed),
 			    buffer);
 
@@ -851,19 +853,19 @@ download_dialog_pause_cb (GtkButton *button, DownloaderView *dv)
 void
 download_dialog_abort_cb (GtkButton *button, DownloaderView *dv)
 {
-	GList *l, *r = NULL;
+	GList *llist, *rlist = NULL, *l, *r;
 	GtkTreeSelection *selection;
 	GtkTreeModel *model;
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW(dv->priv->treeview));
-	l = gtk_tree_selection_get_selected_rows (selection, &model);
-	for (;l != NULL; l = l->next)
+	llist = gtk_tree_selection_get_selected_rows (selection, &model);
+	for (l = llist;l != NULL; l = l->next)
 	{
-		r = g_list_append (r, gtk_tree_row_reference_new
-				   (model, (GtkTreePath *)l->data));
+		rlist = g_list_prepend (rlist, gtk_tree_row_reference_new
+					(model, (GtkTreePath *)l->data));
 	}
 
-        for (; r != NULL; r = g_list_next (r))
+        for (r = rlist; r != NULL; r = r->next)
         {
                 GtkTreeRowReference *node = r->data;
 		GValue val = {0, };
@@ -889,10 +891,9 @@ download_dialog_abort_cb (GtkButton *button, DownloaderView *dv)
                 gtk_tree_row_reference_free (node);
         }
 
-	l = g_list_first (l);
-	g_list_foreach (l, (GFunc)gtk_tree_path_free, NULL);
-        g_list_free (l);
-	g_list_free (r);
+	g_list_foreach (llist, (GFunc)gtk_tree_path_free, NULL);
+	g_list_free (llist);
+	g_list_free (rlist);
 }
 
 static void
