@@ -29,6 +29,7 @@
 enum
 {
 	NEW_WINDOW,
+	CONTEXT_MENU,
 	LINK_MESSAGE,
 	FAVICON,
 	JS_STATUS,
@@ -41,7 +42,6 @@ enum
 	OPEN_URI,
 	SIZE_TO,
 	DOM_MOUSE_CLICK,
-	DOM_MOUSE_DOWN,
 	SECURITY_CHANGE,
 	ZOOM_CHANGE,
 	LAST_SIGNAL
@@ -108,6 +108,16 @@ ephy_embed_base_init (gpointer g_class)
                               G_TYPE_NONE,
                               1,
 			      G_TYPE_STRING);
+	ephy_embed_signals[CONTEXT_MENU] =
+                g_signal_new ("ge_context_menu",
+                              EPHY_EMBED_TYPE,
+                              G_SIGNAL_RUN_LAST,
+                              G_STRUCT_OFFSET (EphyEmbedClass, context_menu),
+                              NULL, NULL,
+                              ephy_marshal_INT__OBJECT,
+                              G_TYPE_INT,
+                              1,
+			      G_TYPE_OBJECT);
 	ephy_embed_signals[FAVICON] =
                 g_signal_new ("ge_favicon",
                               EPHY_EMBED_TYPE,
@@ -209,16 +219,6 @@ ephy_embed_base_init (gpointer g_class)
                               2,
 			      G_TYPE_INT,
 			      G_TYPE_INT);
-	ephy_embed_signals[DOM_MOUSE_DOWN] =
-                g_signal_new ("ge_dom_mouse_down",
-                              EPHY_EMBED_TYPE,
-                              G_SIGNAL_RUN_LAST,
-                              G_STRUCT_OFFSET (EphyEmbedClass, dom_mouse_down),
-                              NULL, NULL,
-                              ephy_marshal_INT__OBJECT,
-                              G_TYPE_INT,
-                              1,
-			      G_TYPE_POINTER);
 	ephy_embed_signals[DOM_MOUSE_CLICK] =
                 g_signal_new ("ge_dom_mouse_click",
                               EPHY_EMBED_TYPE,
