@@ -64,7 +64,7 @@ typedef enum
 	EMBED_FIND_CAP = 1 << 7,
 	EMBED_SCROLL_CAP = 1 << 8,
 	EMBED_SECURITY_CAP = 1 << 9,
-	EMBED_CHARSET_CAP = 1 << 10,
+	EMBED_ENCODING_CAP = 1 << 10,
 	EMBED_SHISTORY_CAP = 1 << 11
 } EmbedCapabilities;
 
@@ -108,11 +108,11 @@ typedef struct
         gboolean print_to_file;
         gchar *printer;
         gchar *file;
-        gint paper;
-        gdouble top_margin;
-        gdouble bottom_margin;
-        gdouble left_margin;
-        gdouble right_margin;
+        gchar *paper;
+        gint top_margin;
+        gint bottom_margin;
+        gint left_margin;
+        gint right_margin;
         gint pages;
         gint from_page;
         gint to_page;
@@ -164,6 +164,8 @@ struct EphyEmbedClass
 {
         GTypeInterface base_iface;
 
+	gint (* context_menu)	 (EphyEmbed *embed,
+				  EphyEmbedEvent *event);
 	void (* favicon)	 (EphyEmbed *embed,
 				  const char *location);
 	void (* link_message)    (EphyEmbed *embed,
@@ -192,8 +194,6 @@ struct EphyEmbedClass
 			          gint height);
 	gint (* dom_mouse_click) (EphyEmbed *embed,
 			          EphyEmbedEvent *event);
-	gint (* dom_mouse_down)  (EphyEmbed *embed,
-				  EphyEmbedEvent *event);
 	void (* security_change) (EphyEmbed *embed,
                                   EmbedSecurityLevel level);
 	void (* zoom_change)	 (EphyEmbed *embed,
@@ -235,10 +235,10 @@ struct EphyEmbedClass
 					    EphyEmbed *source,
 					    EmbedDisplayType display_type);
 	gresult   (* zoom_set)             (EphyEmbed *embed,
-					    int zoom,
+					    float zoom,
 					    gboolean reflow);
 	gresult   (* zoom_get)             (EphyEmbed *embed,
-				            int *zoom);
+				            float *zoom);
 	gresult   (* selection_can_cut)    (EphyEmbed *embed);
 	gresult   (* selection_can_copy)   (EphyEmbed *embed);
 	gresult   (* can_paste)            (EphyEmbed *embed);
@@ -272,8 +272,8 @@ struct EphyEmbedClass
 	gresult   (* print_preview_navigate)	(EphyEmbed *embed,
 						 EmbedPrintPreviewNavType navType,
 						 gint pageNum);
-	gresult   (* set_charset)          (EphyEmbed *embed,
-					    const char *charset);
+	gresult   (* set_encoding)         (EphyEmbed *embed,
+					    const char *encoding);
 };
 
 GType         ephy_embed_get_type             (void);
@@ -337,11 +337,11 @@ gresult	      ephy_embed_copy_page	      (EphyEmbed *dest,
 
 /* Zoom */
 gresult       ephy_embed_zoom_set             (EphyEmbed *embed,
-					       int zoom,
+					       float zoom,
 					       gboolean reflow);
 
 gresult       ephy_embed_zoom_get             (EphyEmbed *embed,
-					       int *zoom);
+					       float *zoom);
 
 /* Clipboard */
 gresult       ephy_embed_selection_can_cut    (EphyEmbed *embed);
@@ -386,8 +386,8 @@ gresult       ephy_embed_get_security_level   (EphyEmbed *embed,
 gresult       ephy_embed_find                 (EphyEmbed *embed,
 					       EmbedFindInfo *find);
 
-gresult       ephy_embed_set_charset          (EphyEmbed *embed,
-					       const char *charset);
+gresult       ephy_embed_set_encoding         (EphyEmbed *embed,
+					       const char *encoding);
 
 /* Printing */
 
