@@ -730,7 +730,11 @@ nsresult EphyWrapper::ForceEncoding (const char *encoding)
 								  &result);
 	if (NS_FAILED(result) || !mdv) return NS_ERROR_FAILURE;
 
+#if MOZILLA_SNAPSHOT > 8
+	result = mdv->SetForceCharacterSet (nsDependentCString(encoding));
+#else
 	result = mdv->SetForceCharacterSet (NS_ConvertUTF8toUCS2(encoding).get());
+#endif
 
 	return result;
 }
