@@ -544,7 +544,6 @@ ephy_node_view_construct (EphyNodeView *view)
 {
 	GtkTreeSelection *selection;
 
-
 	view->priv->nodemodel = ephy_tree_model_node_new (view->priv->root,
 							  view->priv->filter);
 	view->priv->filtermodel = egg_tree_model_filter_new (GTK_TREE_MODEL (view->priv->nodemodel),
@@ -846,6 +845,8 @@ ephy_node_view_init (EphyNodeView *view)
 	view->priv->editable_renderer = NULL;
 	view->priv->editing = TRUE;
 	view->priv->selected_node = NULL;
+
+	gtk_tree_view_set_enable_search (GTK_TREE_VIEW (view), FALSE);
 }
 
 static void
@@ -953,10 +954,6 @@ ephy_node_view_select_node (EphyNodeView *view,
 	GtkTreeIter iter, iter2;
 	GValue val = { 0, };
 	gboolean visible;
-	GtkTreeSelection *selection;
-	GtkTreePath *path;
-
-	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (view));
 
 	g_return_if_fail (node != NULL);
 
@@ -973,10 +970,8 @@ ephy_node_view_select_node (EphyNodeView *view,
 	gtk_tree_model_sort_convert_child_iter_to_iter (GTK_TREE_MODEL_SORT (view->priv->sortmodel),
 							&iter, &iter2);
 
-	path = gtk_tree_model_get_path (GTK_TREE_MODEL (view->priv->sortmodel), &iter);
-	gtk_tree_view_set_cursor (GTK_TREE_VIEW (view),
-				  path, NULL, FALSE);
-	gtk_tree_path_free (path);
+	gtk_tree_selection_select_iter (gtk_tree_view_get_selection (GTK_TREE_VIEW (view)),
+					&iter);
 }
 
 void
