@@ -290,8 +290,8 @@ ephy_zoom_control_class_init (EphyZoomControlClass *klass)
 	g_object_class_install_property (object_class,
 					 PROP_ZOOM,
 					 g_param_spec_float ("zoom",
-							     _("Zoom"),
-							     _("Zoom level to display in the item."),
+							     "Zoom",
+							     "Zoom level to display in the item.",
 							     ZOOM_MINIMAL,
 							     ZOOM_MAXIMAL,
 							     1.0,
