@@ -15,6 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
+ * $Id: ephy-bookmarks-editor.c,v 1.90 2003/06/23 00:34:19 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -35,13 +36,13 @@
 
 #include "ephy-bookmarks-editor.h"
 #include "ephy-bookmark-properties.h"
+#include "ephy-bookmarks-import.h"
 #include "ephy-node-common.h"
 #include "ephy-node-view.h"
 #include "ephy-window.h"
 #include "ephy-dnd.h"
 #include "ephy-prefs.h"
 #include "ephy-shell.h"
-#include "eel-gconf-extensions.h"
 #include "ephy-file-helpers.h"
 #include "egg-action-group.h"
 #include "egg-toggle-action.h"
@@ -53,6 +54,7 @@
 #include "ephy-debug.h"
 #include "ephy-gui.h"
 #include "ephy-stock-icons.h"
+#include "ephy-search-entry.h"
 
 static GtkTargetEntry topic_drag_dest_types [] =
 {
@@ -90,8 +92,6 @@ static void ephy_bookmarks_editor_get_property (GObject *object,
 						GParamSpec *pspec);
 static void ephy_bookmarks_editor_update_menu  (EphyBookmarksEditor *editor);
 
-static void search_entry_changed_cb       (GtkWidget *entry,
-					   EphyBookmarksEditor *editor);
 static void cmd_open_bookmarks_in_tabs    (EggAction *action,
 					   EphyBookmarksEditor *editor);
 static void cmd_open_bookmarks_in_browser (EggAction *action,
@@ -102,6 +102,8 @@ static void cmd_delete			  (EggAction *action,
 				           EphyBookmarksEditor *editor);
 static void cmd_bookmark_properties	  (EggAction *action,
 					   EphyBookmarksEditor *editor);
+static void cmd_bookmarks_import	  (EggAction *action,
+					   EphyBookmarksEditor *editor);
 static void cmd_add_topic		  (EggAction *action,
 					   EphyBookmarksEditor *editor);
 static void cmd_rename			  (EggAction *action,
@@ -172,6 +174,9 @@ static EggActionGroupEntry ephy_bookmark_popup_entries [] = {
 	{ "Properties", N_("_Properties"), GTK_STOCK_PROPERTIES, "<alt>Return",
 	  N_("View or modify the properties of the selected bookmark"), 
 	  G_CALLBACK (cmd_bookmark_properties), NULL },
+	{ "Import", N_("_Import Bookmarks..."), NULL, NULL,
+	  N_("Import bookmarks from another browser or a bookmarks file"), 
+	  G_CALLBACK (cmd_bookmarks_import), NULL },
 	{ "Close", N_("_Close"), GTK_STOCK_CLOSE, "<control>W",
 	  N_("Close the bookmarks window"), 
 	  G_CALLBACK (cmd_close), NULL },
@@ -441,6 +446,114 @@ show_properties_dialog (EphyBookmarksEditor *editor, EphyNode *node)
 	gtk_window_present (GTK_WINDOW (dialog));
 }
 
+static void
+add_bookmarks_source_menu (GtkWidget *menu,
+			   const char *desc,
+			   const char *dir,
+			   const char *filename)
+{
+	GSList *l;
+	char *path;
+
+	path = g_build_filename (g_get_home_dir (), dir, NULL);
+	l = ephy_file_find  (path, filename, 4);
+	g_free (path);
+
+	if (l)
+	{
+		GtkWidget *item;
+
+		item = gtk_menu_item_new_with_label (desc);
+		gtk_widget_show (item);
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+		g_object_set_data_full (G_OBJECT (item), "bookmarks_file",
+					g_strdup (l->data), g_free);
+	}
+
+	g_slist_foreach (l, (GFunc) g_free, NULL);
+	g_slist_free (l);
+}
+
+static void
+import_dialog_response_cb (GtkDialog *dialog, gint response,
+			   GtkWidget *optionmenu)
+{
+	if (response == GTK_RESPONSE_OK)
+	{
+		char *filename;
+		GtkWidget *item, *menu;
+		EphyBookmarks *bookmarks;
+
+		menu = gtk_option_menu_get_menu (GTK_OPTION_MENU (optionmenu));
+		item = gtk_menu_get_active (GTK_MENU (menu));
+		filename = g_object_get_data (G_OBJECT (item), "bookmarks_file");
+
+		bookmarks = ephy_shell_get_bookmarks (ephy_shell);
+		ephy_bookmarks_import (bookmarks, filename);
+	}
+
+	gtk_widget_destroy (GTK_WIDGET (dialog));
+}
+
+static void
+cmd_bookmarks_import (EggAction *action,
+		      EphyBookmarksEditor *editor)
+{
+	GtkWidget *dialog;
+	GtkWidget *label;
+	GtkWidget *vbox;
+	GtkWidget *menu;
+	GtkWidget *option_menu;
+
+	dialog = gtk_dialog_new_with_buttons (_("Import Bookmarks"),
+					     GTK_WINDOW (editor),
+					     GTK_DIALOG_DESTROY_WITH_PARENT |
+					     GTK_DIALOG_NO_SEPARATOR,
+					     GTK_STOCK_CANCEL,
+					     GTK_RESPONSE_CANCEL,
+					     GTK_STOCK_OK,
+					     GTK_RESPONSE_OK,
+					     NULL);
+	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
+	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
+	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 2);
+
+	vbox = gtk_vbox_new (FALSE, 6);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
+	gtk_widget_show (vbox);
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), vbox,
+			    TRUE, TRUE, 0);
+
+	label = gtk_label_new (_("Choose the bookmarks source:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+	gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
+	gtk_widget_show (label);
+
+	menu = gtk_menu_new ();
+	gtk_widget_show (menu);
+
+	add_bookmarks_source_menu (menu, _("Mozilla bookmarks"),
+				   ".mozilla", "bookmarks.html");
+	add_bookmarks_source_menu (menu, _("Galeon bookmarks"),
+				   ".galeon", "bookmarks.xbel");
+	add_bookmarks_source_menu (menu, _("Konqueror bookmarks"),
+				   ".kde/share/apps/konqueror",
+				   "bookmarks.xml");
+
+	option_menu = gtk_option_menu_new ();
+	gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu), menu);
+	gtk_widget_show (option_menu);
+	gtk_box_pack_start (GTK_BOX (vbox), option_menu, TRUE, TRUE, 0);
+
+	g_signal_connect (dialog, "response",
+			  G_CALLBACK (import_dialog_response_cb),
+			  option_menu);
+
+	gtk_widget_show (dialog);
+}
+
 static void
 cmd_bookmark_properties (EggAction *action,
 			 EphyBookmarksEditor *editor)
@@ -851,8 +964,6 @@ static void
 ephy_bookmarks_editor_dispose (GObject *object)
 {
 	EphyBookmarksEditor *editor;
-	long selected_id;
-	char *selected_id_str;
 	GList *selection;
 
 	g_return_if_fail (object != NULL);
@@ -876,15 +987,6 @@ ephy_bookmarks_editor_dispose (GObject *object)
 			return;
 		}
 
-		selected_id = ephy_node_get_id (selection->data);
-		if (selected_id >= 0)
-		{
-			selected_id_str = g_strdup_printf ("%ld", selected_id);
-			eel_gconf_set_string (CONF_BOOKMARKS_SELECTED_NODE,
-					      selected_id_str);
-			g_free (selected_id_str);
-		}
-
 		g_list_free (selection);
 
 		editor->priv->key_view = NULL;
@@ -924,20 +1026,6 @@ key_pressed_cb (EphyNodeView *view,
 	return FALSE;
 }
 
-static void
-reset_search_entry (EphyBookmarksEditor *editor)
-{
-	g_signal_handlers_block_by_func
-		(G_OBJECT (editor->priv->search_entry),
-		 G_CALLBACK (search_entry_changed_cb),
-		 editor);
-	gtk_entry_set_text (GTK_ENTRY (editor->priv->search_entry), "");
-	g_signal_handlers_unblock_by_func
-		(G_OBJECT (editor->priv->search_entry),
-		 G_CALLBACK (search_entry_changed_cb),
-		 editor);
-}
-
 static void
 keyword_node_selected_cb (EphyNodeView *view,
 			  EphyNode *node,
@@ -952,7 +1040,7 @@ keyword_node_selected_cb (EphyNodeView *view,
 	}
 	else
 	{
-		reset_search_entry (editor);
+		ephy_search_entry_clear (EPHY_SEARCH_ENTRY (editor->priv->search_entry));
 		bookmarks_filter (editor, node);
 	}
 }
@@ -969,10 +1057,9 @@ keyword_node_show_popup_cb (GtkWidget *view, EphyBookmarksEditor *editor)
 }
 
 static void
-search_entry_changed_cb (GtkWidget *entry, EphyBookmarksEditor *editor)
+search_entry_search_cb (GtkWidget *entry, const char *search_text, EphyBookmarksEditor *editor)
 {
 	EphyNode *all;
-	char *search_text;
 
 	g_signal_handlers_block_by_func
 		(G_OBJECT (editor->priv->key_view),
@@ -1004,8 +1091,6 @@ search_entry_changed_cb (GtkWidget *entry, EphyBookmarksEditor *editor)
 	ephy_node_filter_done_changing (editor->priv->bookmarks_filter);
 
 	GDK_THREADS_LEAVE ();
-
-	g_free (search_text);
 }
 
 static GtkWidget *
@@ -1020,11 +1105,11 @@ build_search_box (EphyBookmarksEditor *editor)
 	gtk_container_set_border_width (GTK_CONTAINER (box), 6);
 	gtk_widget_show (box);
 
-	entry = gtk_entry_new ();
+	entry = ephy_search_entry_new ();
 	editor->priv->search_entry = entry;
 	gtk_widget_show (entry);
-	g_signal_connect (G_OBJECT (entry), "changed",
-			  G_CALLBACK (search_entry_changed_cb),
+	g_signal_connect (G_OBJECT (entry), "search",
+			  G_CALLBACK (search_entry_search_cb),
 			  editor);
 	add_entry_monitor (editor, entry);
 	add_focus_monitor (editor, entry);
@@ -1111,9 +1196,6 @@ ephy_bookmarks_editor_construct (EphyBookmarksEditor *editor)
 	GtkWidget *bm_view, *key_view;
 	GtkWidget *scrolled_window;
 	EphyNode *node;
-	long selected_id;
-	EphyNode *selected_node;
-	char *selected_id_str;
 	EggMenuMerge *ui_merge;
 	EggActionGroup *action_group;
 	EggAction *action;
@@ -1283,22 +1365,6 @@ ephy_bookmarks_editor_construct (EphyBookmarksEditor *editor)
 	ephy_state_add_paned  (GTK_WIDGET (hpaned),
 			       "bookmarks_paned",
 		               130);
-
-	selected_id_str = eel_gconf_get_string (CONF_BOOKMARKS_SELECTED_NODE);
-	selected_id = g_ascii_strtoull (selected_id_str, NULL, 10);
-	if (selected_id <= 0)
-	{
-		g_free (selected_id_str);
-		return;
-	}
-
-	selected_node = ephy_bookmarks_get_from_id (editor->priv->bookmarks, selected_id);
-	if (selected_node != NULL)
-	{
-		ephy_node_view_select_node (EPHY_NODE_VIEW (key_view), selected_node);
-	}
-
-	g_free (selected_id_str);
 }
 
 void
