@@ -20,6 +20,7 @@
 
 #include "ephy-bookmarks-export.h"
 #include "ephy-node-common.h"
+#include "ephy-file-helpers.h"
 #include "ephy-debug.h"
 
 static void
@@ -57,7 +58,7 @@ add_topics_list (EphyNode *topics, EphyNode *bmk, xmlNodePtr parent)
 	for (l = bmks; l != NULL; l = l->next)
 	{
 		const char *name;
-		EphyNode *node = EPHY_NODE (l->data);
+		EphyNode *node = l->data;
 
 		name = ephy_node_get_property_string
 			(node, EPHY_NODE_KEYWORD_PROP_NAME);
@@ -137,6 +138,6 @@ ephy_bookmarks_export_rdf (EphyBookmarks *bookmarks,
 	}
 	ephy_node_thaw (bmks);
 
-	xmlSaveFormatFile (filename, doc, 1);
+	ephy_file_save_xml (filename, doc);
 	xmlFreeDoc(doc);
 }
