@@ -126,84 +126,6 @@ ephy_shell_class_init (EphyShellClass *klass)
         object_class->finalize = ephy_shell_finalize;
 }
 
-static void
-ephy_shell_command_cb (EphyEmbedShell *shell,
-		       char *command,
-		       char *param,
-		       gpointer data)
-{
-	EphyBookmarks *bookmarks;
-	GtkWidget *dialog;
-	const gchar *message = NULL;
-	GtkMessageType message_type = GTK_MESSAGE_INFO;
-	EphyWindow *window;
-
-	bookmarks = ephy_shell_get_bookmarks (EPHY_SHELL (shell));
-
-	if (strcmp (command, "import-mozilla-bookmarks") == 0)
-	{
-		if (ephy_bookmarks_import_mozilla (bookmarks, param))
-		{
-			message_type =  GTK_MESSAGE_INFO;
-			message = _("Mozilla bookmarks imported successfully.");
-		}
-		else
-		{
-			message_type = GTK_MESSAGE_ERROR;
-			message = _("Importing Mozilla bookmarks failed.");
-		}
-	}
-	else if (strcmp (command, "import-galeon-bookmarks") == 0)
-	{
-		if (ephy_bookmarks_import_xbel (bookmarks, param,
-						_("Galeon")))
-		{
-			message_type = GTK_MESSAGE_INFO;
-			message = _("Galeon bookmarks imported successfully.");
-		}
-		else
-		{
-			message_type = GTK_MESSAGE_ERROR;
-			message = _("Importing Galeon bookmarks failed.");
-		}
-	}
-	else if (strcmp (command, "import-konqueror-bookmarks") == 0)
-	{
-		if (ephy_bookmarks_import_xbel (bookmarks, param,
-						_("Konqueror")))
-		{
-			message_type = GTK_MESSAGE_INFO;
-			message = _("Konqueror bookmarks imported successfully.");
-		}
-		else
-		{
-			message_type = GTK_MESSAGE_ERROR;
-			message = _("Importing Konqueror bookmarks failed.");
-		}
-	}
-	else if (strcmp (command, "configure-network") == 0)
-	{
-		ephy_file_launch_application ("gnome-network-preferences",
-					      NULL,
-					      FALSE);
-	}
-
-	if (message != NULL)
-	{
-		window = ephy_shell_get_active_window (EPHY_SHELL (shell));
-		dialog = gtk_message_dialog_new (GTK_WINDOW (window),
-				 		 GTK_DIALOG_DESTROY_WITH_PARENT,
-				 		 message_type,
-				 		 GTK_BUTTONS_OK,
-				 		 message);
-		gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
-		g_signal_connect_swapped (G_OBJECT (dialog), "response",
-                           		  G_CALLBACK (gtk_widget_destroy),
-                           		  G_OBJECT (dialog));
-		gtk_widget_show (dialog);
-	}
-}
-
 static void
 ephy_shell_new_window_cb (EphyEmbedShell *shell,
 			  EphyEmbed **new_embed,
@@ -227,6 +149,7 @@ static void
 ephy_shell_init (EphyShell *gs)
 {
 	EphyEmbedSingle *single;
+	EphyShell **ptr = &ephy_shell;
 
         gs->priv = g_new0 (EphyShellPrivate, 1);
 	gs->priv->session = NULL;
@@ -237,7 +160,7 @@ ephy_shell_init (EphyShell *gs)
 
 	ephy_shell = gs;
 	g_object_add_weak_pointer (G_OBJECT(ephy_shell),
-				   (gpointer *)&ephy_shell);
+				   (gpointer *)ptr);
 
 	ephy_debug_init ();
 	ephy_thread_helpers_init ();
@@ -253,11 +176,6 @@ ephy_shell_init (EphyShell *gs)
 			  G_CALLBACK(ephy_shell_new_window_cb),
 			  NULL);
 
-	g_signal_connect (G_OBJECT (gs),
-			  "command",
-			  G_CALLBACK(ephy_shell_command_cb),
-			  NULL);
-
 	ephy_init_services (gs);
 }
 
@@ -481,23 +399,12 @@ ephy_shell_new_tab (EphyShell *shell,
 			     jump_to);
 	gtk_widget_show (GTK_WIDGET(window));
 
-	if (flags & EPHY_NEW_TAB_HOME_PAGE)
+	if (flags & EPHY_NEW_TAB_HOME_PAGE ||
+	    flags & EPHY_NEW_TAB_NEW_PAGE)
 	{
-		toolbar_edit_location (toolbar);
-
-		load_homepage (embed);
-	}
-	else if (flags & EPHY_NEW_TAB_NEW_PAGE)
-	{
-		char *previous_address = NULL;
-
-		g_return_val_if_fail (previous_embed != NULL, NULL);
-		ephy_embed_get_location (previous_embed, TRUE,
-					 &previous_address);
-		toolbar_set_location (toolbar, previous_address);
-		toolbar_edit_location (toolbar);
-
+		ephy_tab_set_location (tab, "", TAB_ADDRESS_EXPIRE_NEXT);
 		load_homepage (embed);
+		toolbar_activate_location (toolbar);
 	}
 	else if (flags & EPHY_NEW_TAB_OPEN_PAGE)
 	{
@@ -517,8 +424,7 @@ ephy_shell_new_tab (EphyShell *shell,
 
 	if (flags & EPHY_NEW_TAB_FULLSCREEN_MODE)
 	{
-		ephy_window_set_chrome (window, EMBED_CHROME_OPENASFULLSCREEN |
-				        EMBED_CHROME_DEFAULT);
+		gtk_window_fullscreen (GTK_WINDOW (window));
 	}
 
         return tab;
@@ -716,4 +622,3 @@ ephy_shell_show_history_window (EphyShell *gs,
 
 	gtk_window_present (GTK_WINDOW (gs->priv->history_window));
 }
-
