@@ -22,6 +22,7 @@
 #include "ephy-embed.h"
 #include "ephy-dialog.h"
 #include "ephy-notebook.h"
+
 #include <glib-object.h>
 #include <glib.h>
 #include <gtk/gtkwindow.h>
@@ -62,20 +63,6 @@ typedef enum
 
 typedef enum
 {
-	NavControl,
-	FindControl,
-	ZoomControl,
-	EncodingsControl,
-	TitleControl,
-	LocationControl,
-	FaviconControl,
-	StatusbarSecurityControl,
-	StatusbarMessageControl,
-	StatusbarProgressControl,
-	SpinnerControl,
-	WindowVisibilityControl,
-	BMAndHistoryControl,
-	TabsAppeareanceControl,
 	FavoritesControl
 } ControlID;
 
@@ -115,8 +102,6 @@ void		  ephy_window_activate_location	  (EphyWindow *window);
 void		  ephy_window_update_control	  (EphyWindow *window,
 						   ControlID control);
 
-void		  ephy_window_update_all_controls (EphyWindow *window);
-
 EphyTab		 *ephy_window_get_active_tab	  (EphyWindow *window);
 
 EphyEmbed	 *ephy_window_get_active_embed	  (EphyWindow *window);
@@ -129,6 +114,8 @@ Toolbar		 *ephy_window_get_toolbar	  (EphyWindow *window);
 
 EphyDialog       *ephy_window_get_find_dialog	  (EphyWindow *window);
 
+void		  ephy_window_print		  (EphyWindow *window);
+
 G_END_DECLS
 
 #endif
