@@ -81,7 +81,7 @@ struct ToolbarPrivate
 	EggMenuMerge *ui_merge;
 	EggActionGroup *action_group;
 	gboolean visibility;
-	GtkWidget *location_entry;
+	gboolean can_set_location;
 	GtkWidget *spinner;
 	GtkWidget *favicon;
 	GtkWidget *go;
@@ -195,7 +195,7 @@ toolbar_ensure_action (Toolbar *t,
 	{
 		EphyNode *node;
 
-		if (!ephy_str_to_int (name + strlen ("GoBookmarkId"), &id))
+		if (!ephy_string_to_int (name + strlen ("GoBookmarkId"), &id))
 		{
 			return;
 		}
@@ -218,7 +218,7 @@ toolbar_ensure_action (Toolbar *t,
 	{
 		EphyNode *node;
 
-		if (!ephy_str_to_int (name + strlen ("GoTopicId"), &id))
+		if (!ephy_string_to_int (name + strlen ("GoTopicId"), &id))
 		{
 			return;
 		}
@@ -457,6 +457,36 @@ update_toolbar_remove_flag (EphyToolbarsModel *model, gpointer data)
 	}
 }
 
+static GtkWidget *
+get_location_entry (Toolbar *t)
+{
+	EggAction *action;
+	GtkWidget *location;
+
+	action = egg_action_group_get_action
+		(t->priv->action_group, "Location");
+	location = ephy_location_action_get_widget
+		(EPHY_LOCATION_ACTION (action));
+
+	return location;
+}
+
+static void
+location_user_changed_cb (GtkWidget *entry, Toolbar *t)
+{
+	EphyTab *tab;
+	char *address;
+
+	tab = ephy_window_get_active_tab (t->priv->window);
+	g_return_if_fail (IS_EPHY_TAB (tab));
+
+	t->priv->can_set_location = FALSE;
+	address = ephy_location_entry_get_location (EPHY_LOCATION_ENTRY (entry));
+	ephy_tab_set_location (tab, address, TAB_ADDRESS_EXPIRE_CURRENT);
+	g_free (address);
+	t->priv->can_set_location = TRUE;
+}
+
 static void
 toolbar_set_window (Toolbar *t, EphyWindow *window)
 {
@@ -487,6 +517,10 @@ toolbar_set_window (Toolbar *t, EphyWindow *window)
 		      "MenuMerge", t->priv->ui_merge,
 		      NULL);
 	init_bookmarks_toolbar (t);
+
+	g_signal_connect_object (get_location_entry (t), "user_changed",
+			         G_CALLBACK (location_user_changed_cb),
+			         t, 0);
 }
 
 static void
@@ -497,6 +531,7 @@ toolbar_init (Toolbar *t)
 	t->priv->window = NULL;
 	t->priv->ui_merge = NULL;
 	t->priv->visibility = TRUE;
+	t->priv->can_set_location = TRUE;
 }
 
 static void
@@ -539,22 +574,6 @@ toolbar_new (EphyWindow *window)
 	return t;
 }
 
-void
-toolbar_edit_location (Toolbar *t)
-{
-	EggAction *action;
-	GtkWidget *location;
-
-	action = egg_action_group_get_action
-		(t->priv->action_group, "Location");
-	location = ephy_location_action_get_widget
-		(EPHY_LOCATION_ACTION (action));
-	g_return_if_fail (location != NULL);
-
-	ephy_location_entry_edit
-		(EPHY_LOCATION_ENTRY(location));
-}
-
 static void
 location_finished_cb (GtkWidget *location, GtkWidget *toolbar)
 {
@@ -568,14 +587,10 @@ location_finished_cb (GtkWidget *location, GtkWidget *toolbar)
 void
 toolbar_activate_location (Toolbar *t)
 {
-	EggAction *action;
 	GtkWidget *location;
 	GtkWidget *location_tb;
 
-	action = egg_action_group_get_action
-		(t->priv->action_group, "Location");
-	location = ephy_location_action_get_widget
-		(EPHY_LOCATION_ACTION (action));
+	location = get_location_entry (t);
 	g_return_if_fail (location != NULL);
 
 	location_tb = gtk_widget_get_ancestor (location, EGG_TYPE_TOOLBAR);
@@ -618,17 +633,17 @@ void
 toolbar_set_location (Toolbar *t,
 		      const char *alocation)
 {
-	EggAction *action;
 	GtkWidget *location;
 
-	action = egg_action_group_get_action
-		(t->priv->action_group, "Location");
-	location = ephy_location_action_get_widget
-		(EPHY_LOCATION_ACTION (action));
-	g_return_if_fail (location != NULL);
+	if (t->priv->can_set_location)
+	{
+		location = get_location_entry (t);
+		g_return_if_fail (location != NULL);
 
-	ephy_location_entry_set_location
-		(EPHY_LOCATION_ENTRY (location), alocation);
+		ephy_location_entry_set_location
+			(EPHY_LOCATION_ENTRY (location),
+			 alocation ? alocation : "");
+	}
 }
 
 void
@@ -640,7 +655,7 @@ toolbar_update_favicon (Toolbar *t)
 	EggAction *action;
 
 	tab = ephy_window_get_active_tab (t->priv->window);
-	url = ephy_tab_get_favicon_url (tab);
+	url = ephy_tab_get_icon_address (tab);
 	action_group = t->priv->action_group;
 	action = egg_action_group_get_action (action_group, "Favicon");
 	g_object_set (action, "icon", url, NULL);
@@ -649,13 +664,9 @@ toolbar_update_favicon (Toolbar *t)
 char *
 toolbar_get_location (Toolbar *t)
 {
-	EggAction *action;
 	GtkWidget *location;
 
-	action = egg_action_group_get_action
-		(t->priv->action_group, "Location");
-	location = ephy_location_action_get_widget
-		(EPHY_LOCATION_ACTION (action));
+	location = get_location_entry (t);
 	g_return_val_if_fail (location != NULL, NULL);
 
 	return ephy_location_entry_get_location
@@ -665,13 +676,9 @@ toolbar_get_location (Toolbar *t)
 void
 toolbar_clear_location_history (Toolbar *t)
 {
-	EggAction *action;
 	GtkWidget *location;
 
-	action = egg_action_group_get_action
-		(t->priv->action_group, "Location");
-	location = ephy_location_action_get_widget
-		(EPHY_LOCATION_ACTION (action));
+	location = get_location_entry (t),
 	g_return_if_fail (location != NULL);
 
 	ephy_location_entry_clear_history (EPHY_LOCATION_ENTRY (location));
@@ -685,11 +692,11 @@ toolbar_update_navigation_actions (Toolbar *t, gboolean back, gboolean forward,
 
 	action_group = t->priv->action_group;
 	action = egg_action_group_get_action (action_group, "NavigationBack");
-	g_object_set (action, "sensitive", !back, NULL);
+	g_object_set (action, "sensitive", back, NULL);
 	action = egg_action_group_get_action (action_group, "NavigationForward");
-	g_object_set (action, "sensitive", !forward, NULL);
+	g_object_set (action, "sensitive", forward, NULL);
 	action = egg_action_group_get_action (action_group, "NavigationUp");
-	g_object_set (action, "sensitive", !up, NULL);
+	g_object_set (action, "sensitive", up, NULL);
 }
 
 void
