@@ -14,6 +14,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: window-commands.c,v 1.66 2003/06/23 09:57:21 mpeseng Exp $
  */
 
 #include <config.h>
@@ -64,31 +66,11 @@ window_cmd_edit_find (EggAction *action,
 	ephy_dialog_show (dialog);
 }
 
-static void
-print_dialog_preview_cb (PrintDialog *dialog,
-			 EphyWindow *window)
-{
-	ephy_window_set_chrome (window, EMBED_CHROME_PPVIEWTOOLBARON);
-}
-
 void
 window_cmd_file_print (EggAction *action,
 		       EphyWindow *window)
 {
-	EphyDialog *dialog;
-	EphyEmbed *embed;
-
-	embed = ephy_window_get_active_embed (window);
-	g_return_if_fail (embed != NULL);
-
-	dialog = print_dialog_new_with_parent (GTK_WIDGET(window),
-					       embed, NULL);
-	g_signal_connect (G_OBJECT(dialog),
-			  "preview",
-			  G_CALLBACK (print_dialog_preview_cb),
-			  window);
-	ephy_dialog_set_modal (dialog, TRUE);
-	ephy_dialog_show (dialog);
+	ephy_window_print (window);
 }
 
 void
@@ -119,19 +101,23 @@ void
 window_cmd_file_send_to	(EggAction *action,
 			 EphyWindow *window)
 {
-	char *url;
 	EphyTab *tab;
 	EphyEmbed *embed;
+	char *url;
+	char *embed_location;
 	char *location;
 	char *title;
 
 	tab = ephy_window_get_active_tab (window);
-	g_return_if_fail (tab);
+	g_return_if_fail (tab != NULL);
 
 	embed = ephy_window_get_active_embed (window);
-	g_return_if_fail (tab);
+	g_return_if_fail (embed != NULL);
+
+	ephy_embed_get_location (embed, TRUE, &embed_location);
+	location = gnome_vfs_escape_string (embed_location);
+	g_free (embed_location);
 
-	location = gnome_vfs_escape_string (ephy_tab_get_location (tab));
 	if (ephy_embed_get_title (embed, &title) == G_OK)
 	{
 		char *tmp = gnome_vfs_escape_string (title);
@@ -246,6 +232,7 @@ window_cmd_file_new_window (EggAction *action,
 	EphyTab *tab;
 
 	tab = ephy_window_get_active_tab (window);
+	g_return_if_fail (tab != NULL);
 
 	ephy_shell_new_tab (ephy_shell, NULL, tab, NULL,
 			    EPHY_NEW_TAB_NEW_PAGE |
@@ -259,11 +246,12 @@ window_cmd_file_new_tab (EggAction *action,
 	EphyTab *tab;
 
 	tab = ephy_window_get_active_tab (window);
+	g_return_if_fail (tab != NULL);
 
 	ephy_shell_new_tab (ephy_shell, window, tab, NULL,
-			      EPHY_NEW_TAB_NEW_PAGE |
-			      EPHY_NEW_TAB_IN_EXISTING_WINDOW |
-			      EPHY_NEW_TAB_JUMP);
+			    EPHY_NEW_TAB_NEW_PAGE |
+			    EPHY_NEW_TAB_IN_EXISTING_WINDOW |
+			    EPHY_NEW_TAB_JUMP);
 }
 
 void
@@ -275,29 +263,30 @@ window_cmd_go_bookmarks (EggAction *action,
 
 void
 window_cmd_file_bookmark_page (EggAction *action,
-			      EphyWindow *window)
+			       EphyWindow *window)
 {
 	EphyTab *tab;
 	EphyEmbed *embed;
 	EphyBookmarks *bookmarks;
 	GtkWidget *new_bookmark;
-	const char *location;
+	char *location;
 	const char *icon;
-	char *title;
+	char *title = NULL;
 
 	tab = ephy_window_get_active_tab (window);
-	g_return_if_fail (tab);
+	g_return_if_fail (tab != NULL);
 
 	embed = ephy_window_get_active_embed (window);
-	g_return_if_fail (tab);
+	g_return_if_fail (embed != NULL);
+
+	ephy_embed_get_location (embed, TRUE, &location);
 
-	location = ephy_tab_get_location (tab);
 	if (ephy_embed_get_title (embed, &title) != G_OK)
 	{
-		title = _("Untitled");
+		title = g_strdup (_("Untitled"));
 	}
 
-	icon = ephy_tab_get_favicon_url (tab);
+	icon = ephy_tab_get_icon_address (tab);
 
 	bookmarks = ephy_shell_get_bookmarks (ephy_shell);
 	if (ephy_new_bookmark_is_unique (bookmarks, GTK_WINDOW (window),
@@ -311,6 +300,9 @@ window_cmd_file_bookmark_page (EggAction *action,
 			(EPHY_NEW_BOOKMARK (new_bookmark), icon);
 		gtk_widget_show (new_bookmark);
 	}
+
+	g_free (title);
+	g_free (location);
 }
 
 void
@@ -341,26 +333,25 @@ window_cmd_file_open (EggAction *action,
                  dir, NULL, modeOpen,
                  &file, NULL, NULL);
 
-	if (result == G_OK)
+	uri = gnome_vfs_uri_new (file);
+	if (uri)
 	{
-                uri = gnome_vfs_uri_new (file);
-                if (uri)
-                {
+		retDir = gnome_vfs_uri_extract_dirname (uri);
 
-                        ephy_window_load_url(window, file);
+		/* set default open dir */
+		eel_gconf_set_string (CONF_STATE_OPEN_DIR,
+				      retDir);
 
-                        retDir = gnome_vfs_uri_extract_dirname (uri);
+		g_free (retDir);
+		gnome_vfs_uri_unref (uri);
 
-                        /* set default open dir */
-                        eel_gconf_set_string (CONF_STATE_OPEN_DIR,
-                                              retDir);
-
-                        g_free (retDir);
-                        gnome_vfs_uri_unref (uri);
-                }
-	        g_free (file);
-        }
+		if (result == G_OK)
+		{
+			ephy_window_load_url(window, file);
+	        }
+	}
 
+	g_free (file);
         g_free (dir);
 }
 
@@ -376,7 +367,7 @@ window_cmd_file_save_as (EggAction *action,
 
 	persist = ephy_embed_persist_new (embed);
 	ephy_embed_persist_set_flags (persist,
-					EMBED_PERSIST_MAINDOC);
+				      EMBED_PERSIST_MAINDOC);
 
 	ephy_embed_utils_save (GTK_WIDGET(window),
 			       CONF_STATE_SAVE_DIR,
@@ -389,7 +380,7 @@ window_cmd_file_save_as (EggAction *action,
 
 void
 window_cmd_file_close_window (EggAction *action,
-		               EphyWindow *window)
+		              EphyWindow *window)
 {
 	EphyTab *tab;
 
@@ -491,8 +482,6 @@ window_cmd_edit_find_next (EggAction *action,
 	dialog = ephy_window_get_find_dialog (window);
 
 	find_dialog_go_next (FIND_DIALOG(dialog), FALSE);
-
-	ephy_window_update_control (window, FindControl);
 }
 
 void
@@ -504,8 +493,6 @@ window_cmd_edit_find_prev (EggAction *action,
 	dialog = ephy_window_get_find_dialog (window);
 
 	find_dialog_go_prev (FIND_DIALOG(dialog), FALSE);
-
-	ephy_window_update_control (window, FindControl);
 }
 
 void
@@ -569,19 +556,13 @@ void
 window_cmd_view_fullscreen (EggAction *action,
 			    EphyWindow *window)
 {
-	EmbedChromeMask mask;
-	gboolean active;
-	gboolean current_state;
-
-	mask = ephy_window_get_chrome (window);
-	active = EGG_TOGGLE_ACTION (action)->active;
-	current_state = (mask & EMBED_CHROME_OPENASFULLSCREEN) > 0;
-
-	if (active != current_state)
+	if (EGG_TOGGLE_ACTION (action)->active)
 	{
-		mask ^= EMBED_CHROME_OPENASFULLSCREEN;
-		mask |= EMBED_CHROME_DEFAULT;
-		ephy_window_set_chrome (window, mask);
+		gtk_window_fullscreen (GTK_WINDOW (window));
+	}
+	else
+	{
+		gtk_window_unfullscreen (GTK_WINDOW (window));
 	}
 }
 
@@ -745,6 +726,7 @@ window_cmd_help_about (EggAction *action,
 		       GtkWidget *window)
 {
 	static GtkWidget *about = NULL;
+	GtkWidget** ptr;
 	GdkPixbuf *icon;
 	const char *icon_path;
 	GdkPixbuf *logo;
@@ -753,6 +735,7 @@ window_cmd_help_about (EggAction *action,
 		"Marco Pesenti Gritti <mpeseng@tin.it>",
 		"Xan Lopez <xan@masilla.org>",
 		"David Bordoley <bordoley@msu.edu>",
+		"Christian Persch <chpe+epiphany@stud.uni-saarland.de>",
 		NULL
 	};
 
@@ -798,7 +781,8 @@ window_cmd_help_about (EggAction *action,
 	gtk_window_set_icon (GTK_WINDOW (about), icon);
 	g_object_unref(icon);
 
-	g_object_add_weak_pointer (G_OBJECT (about), (gpointer *)&about);
+	ptr = &about;
+	g_object_add_weak_pointer (G_OBJECT (about), (gpointer *)ptr);
 	gtk_widget_show (about);
 }
 
@@ -806,21 +790,18 @@ void
 window_cmd_tabs_next (EggAction *action,
 		      EphyWindow *window)
 {
-	GList *tabs;
-	EphyTab *tab;
+	GtkNotebook *nb;
+	gint page;
 
-	tab = ephy_window_get_active_tab (window);
-	tabs = ephy_window_get_tabs (window);
-	g_return_if_fail (tab != NULL);
+	nb = GTK_NOTEBOOK (ephy_window_get_notebook (window));
+	g_return_if_fail (nb != NULL);
 
-	tabs = g_list_find (tabs, (gpointer)tab);
-	tabs = tabs->next;
+	page = gtk_notebook_get_current_page (nb);
+	g_return_if_fail (page != -1);
 
-	if (tabs)
+	if (page < gtk_notebook_get_n_pages (nb) - 1)
 	{
-		tab = EPHY_TAB (tabs->data);
-		ephy_window_jump_to_tab (window, tab);
-		g_list_free (tabs);
+		gtk_notebook_set_current_page (nb, page + 1);
 	}
 }
 
@@ -828,21 +809,18 @@ void
 window_cmd_tabs_previous (EggAction *action,
 			  EphyWindow *window)
 {
-	GList *tabs;
-	EphyTab *tab;
+	GtkNotebook *nb;
+	gint page;
 
-	tab = ephy_window_get_active_tab (window);
-	tabs = ephy_window_get_tabs (window);
-	g_return_if_fail (tab != NULL);
+	nb = GTK_NOTEBOOK (ephy_window_get_notebook (window));
+	g_return_if_fail (nb != NULL);
 
-	tabs = g_list_find (tabs, (gpointer)tab);
-	tabs = tabs->prev;
+	page = gtk_notebook_get_current_page (nb);
+	g_return_if_fail (page != -1);
 
-	if (tabs)
+	if (page > 0)
 	{
-		tab = EPHY_TAB (tabs->data);
-		ephy_window_jump_to_tab (window, tab);
-		g_list_free (tabs);
+		gtk_notebook_set_current_page (nb, page - 1);
 	}
 }
 
@@ -890,13 +868,11 @@ window_cmd_tabs_detach  (EggAction *action,
 			 EphyWindow *window)
 {
 	EphyTab *tab;
-	GtkWidget *src_page;
+	GtkWidget *src_page, *nb;
 	EphyWindow *new_win;
 
-	if (g_list_length (ephy_window_get_tabs (window)) <= 1)
-	{
-		return;
-	}
+	nb = ephy_window_get_notebook (window);
+	if (gtk_notebook_get_n_pages (GTK_NOTEBOOK (nb)) <= 1) return;
 
 	tab = ephy_window_get_active_tab (window);
 	src_page = GTK_WIDGET (ephy_tab_get_embed (tab));
